summaryrefslogtreecommitdiff
path: root/usr.bin/vim/cmdline.c
diff options
context:
space:
mode:
authorJason Downs <downsj@cvs.openbsd.org>1996-10-14 03:56:09 +0000
committerJason Downs <downsj@cvs.openbsd.org>1996-10-14 03:56:09 +0000
commit0a64da4f22aa6e7dc9ce23604386381860186ad4 (patch)
tree532d8d1430151973edf5c77219a3c0c08afbd3d4 /usr.bin/vim/cmdline.c
parent6ddf388c16e872b21b49b92394473229e943f96e (diff)
Backout a previous change that didn't work, and update to version 4.5.
Diffstat (limited to 'usr.bin/vim/cmdline.c')
-rw-r--r--usr.bin/vim/cmdline.c14
1 files changed, 10 insertions, 4 deletions
diff --git a/usr.bin/vim/cmdline.c b/usr.bin/vim/cmdline.c
index 7e50783fdb0..9c0ce156ad0 100644
--- a/usr.bin/vim/cmdline.c
+++ b/usr.bin/vim/cmdline.c
@@ -1,4 +1,4 @@
-/* $OpenBSD: cmdline.c,v 1.4 1996/09/22 01:18:00 downsj Exp $ */
+/* $OpenBSD: cmdline.c,v 1.5 1996/10/14 03:55:08 downsj Exp $ */
/* vi:set ts=4 sw=4:
*
* VIM - Vi IMproved by Bram Moolenaar
@@ -300,8 +300,13 @@ getcmdline(firstc, count)
c = hkmap(c);
#endif
}
- if (c == Ctrl('C'))
- got_int = FALSE; /* ignore got_int when CTRL-C was typed here */
+
+ /*
+ * Ignore got_int when CTRL-C was typed here.
+ * Don't ignore it in :global, we really need to break then.
+ */
+ if (c == Ctrl('C') && !global_busy)
+ got_int = FALSE;
/* free old command line when finished moving around in the
* history list */
@@ -4529,7 +4534,8 @@ showmatches(buff)
flushbuf(); /* show one line at a time */
if (got_int)
{
- got_int = FALSE;
+ if (!global_busy)
+ got_int = FALSE;
break;
}
}